@@ -26,7 +26,7 @@ runTests <- FALSE
 ##
 ## Set this variable manually if you want to run the tests
 ##
-if (Sys.getenv("RunFOAASTests=yes") == "yes") runTests <- TRUE
+if (Sys.getenv("RunFOAASTests") == "yes") runTests <- TRUE
 
 ## Also run the tests when building on Dirk's box, even whem
 ## the environment variable is not set
@@ -56,8 +56,8 @@ if (runTests) {
     stopifnot(donut       (name=name, from=from)  == "Someone, go and take a flying fuck at a rolling donut. - Me")
     stopifnot(shakespeare (name=name, from=from)  == "Someone, Thou clay-brained guts, thou knotty-pated fool, thou whoreson obscene greasy tallow-catch! - Me")
     stopifnot(linus       (name=name, from=from)  == "Someone, there aren't enough swear-words in the English language, so now I'll have to call you perkeleen vittupää just to express my disgust and frustration with this crap. - Me" )
-    stopifnot(king        (name=name, from=from)  == "Oh fuck off, just really fuck off you total dickface. Christ Someone, you are fucking thick. - Me" )
-    stopifnot(pink        (name=name)             == "Well, Fuck me pink. - Someone")
+    stopifnot(king        (name=name, from=from)  == "Oh fuck off, just really fuck off you total dickface. Christ, Someone, you are fucking thick. - Me" )
+    stopifnot(pink        (name=name)             == "Well, fuck me pink. - Someone")
     stopifnot(life        (name=name)             == "Fuck my life. - Someone")
     stopifnot(chainsaw    (name=name, from=from)  == "Fuck me gently with a chainsaw, Someone. Do I look like Mother Teresa? - Me")
     stopifnot(outside     (name=name, from=from)  == "Someone, why don't you go outside and play hide-and-go-fuck-yourself? - Me")
@@ -75,7 +75,7 @@ if (runTests) {
                            from=from)             == "Fucking Someone is a fucking pussy. I'm going to fucking bury that guy, I have done it before, and I will do it again. I'm going to fucking kill XYZ Corp. - Me")
 
     stopifnot(what        (from=from)             == "What the fuck‽ - Me")
-    stopifnot(because     (from=from)             == "Why? Because Fuck you, that's why. - Me")
+    stopifnot(because     (from=from)             == "Why? Because fuck you, that's why. - Me")
     stopifnot(caniuse     (tool=tool, from=from)  == "Can you use Some magic thing? Fuck no! - Me")
     stopifnot(bye         (from=from)             == "Fuckity bye! - Me")
     stopifnot(diabetes    (from=from)             == "I'd love to stop and chat to you but I'd rather have type 2 diabetes. - Me")
@@ -97,11 +97,14 @@ if (runTests) {
     ##off_with
     stopifnot(retard      (from=from)             == "You Fucktard! - Me")
     stopifnot(thumbs      (name=name, from=from)  == "Who has two thumbs and doesn't give a fuck? Someone. - Me")
+    stopifnot(back        (name=name, from=from)  == "Someone, back the fuck off. - Me")
+    stopifnot(bm          (name=name, from=from)  == "Bravo mike, Someone. - Me")
+    stopifnot(gfy         (name=name, from=from)  == "Golf foxtrot yankee, Someone. - Me")
     stopifnot(greed       (something=something,
                            from=from)             == "The point is, ladies and gentleman, that something -- for lack of a better word -- is good. Something is right. Something works. Something clarifies, cuts through, and captures the essence of the evolutionary spirit. Something, in all of its forms -- Something for life, for money, for love, knowledge -- has marked the upward surge of mankind. - Me")
 
     stopifnot(me          (from=from)             == "Fuck me. - Me")
-    stopifnot(mornin      (from=from)             == "Happy fuckin' Mornin'! - Me")
+    stopifnot(mornin      (from=from)             == "Happy fuckin' mornin'! - Me")
 
     stopifnot(think	  (name=name, from=from)  == "Someone, you think I give a fuck? - Me")
     stopifnot(keep	  (name=name, from=from)  == "Someone: Fuck off. And when you get there, fuck off from there too. Then fuck off some more. Keep fucking off until you get back here. Then fuck off again. - Me")
@@ -118,10 +121,18 @@ if (runTests) {
     stopifnot(blackadder  (name=name, from=from)  == "Someone, your head is as empty as a eunuch’s underpants. Fuck off! - Me")
     stopifnot(horse       (from=from)             == "Fuck you and the horse you rode in on. - Me")
     stopifnot(deraadt     (name=name, from=from)  == "Someone you are being the usual slimy hypocritical asshole... You may have had value ten years ago, but people will see that you don't anymore. - Me")
-    stopifnot(problem     (name=name, from=from)  == "What the fuck is you problem Someone? - Me")
+    stopifnot(problem     (name=name, from=from)  == "What the fuck is your problem Someone? - Me")
     stopifnot(cocksplat   (name=name, from=from)  == "Fuck off Someone, you worthless cocksplat - Me")
     stopifnot(too         (from=from)             == "Thanks, fuck you too. - Me")
 
+    stopifnot(asshole	  (from=from)             == "Fuck you, asshole. - Me")
+    stopifnot(cup	  (from=from)             == "How about a nice cup of shut the fuck up? - Me")
+    stopifnot(fyyff	  (from=from)             == "Fuck you, you fucking fuck. - Me")
+    stopifnot(immensity	  (from=from)             == "You can not imagine the immensity of the FUCK I do not give. - Me")
+    stopifnot(programmer  (from=from)  		  == "Fuck you, I'm a programmer, bitch! - Me")
+    stopifnot(rtfm	  (from=from)	  	  == "Read the fucking manual! - Me")
+    stopifnot(thinking    (name=name, from=from)  == "Someone, what the fuck were you actually thinking? - Me")
+
     stopifnot(thing       (name=name, from=from)  == "Fuck Someone. - Me")
 
     ## shoutcloud
@@ -133,5 +144,16 @@ if (runTests) {
     ## shoutcloud and language -- cannot test, responses change
     #stopifnot(off         (name=name, from=from, filter="shoutcloud", language="de")  == "FUCK OFF JEMAND. - ME")
 
+    ## cover randomFO
+    set.seed(123)
+    stopifnot(getRandomFO(name=name, from=from)  == "You Fucktard! - Me")
+
+    set.seed(42)
+    stopifnot(getRandomFO(name="Someone", from="Me") == "Who the fuck are you anyway, Someone, why are you stirring up so much trouble, and, who pays you? - Me")
+
+    v <- version()
+    op <- operations()
+    print(getRandomFO(name=name))
+
 }
 
